@@ -1,5 +1,5 @@
-/* 
- *  at.c : Put file into atrun queue
+/*
+ *  at.c : Put file into atd queue
  *  Copyright (C) 1993, 1994, 1995, 1996, 1997 Thomas Koenig
  *  Copyright (C) 2002, 2005 Ryan Murray
  *
@@ -94,6 +94,9 @@
 #define TIMEFORMAT_POSIX	"%a %b %e %T %Y"
 #define TIMESIZE	50
 
+#define DEFAULT_QUEUE 'a'
+#define BATCH_QUEUE   'b'
+
 enum {
     ATQ, BATCH, ATRM, AT, CAT
 };				/* what program we want to run */
@@ -722,12 +725,12 @@ int
 main(int argc, char **argv)
 {
     int c;
-    char queue = DEFAULT_AT_QUEUE;
+    char queue = DEFAULT_QUEUE;
     char queue_set = 0;
     char *pgm;
 
     int program = AT;		/* our default program */
-    char *options = "q:f:MmvldhVct:";	/* default options for at */
+    char *options = "q:f:MmvlrdhVct:";	/* default options for at */
     int disp_version = 0;
     time_t timer = 0;
     struct passwd *pwe;
@@ -903,10 +906,10 @@ main(int argc, char **argv)
     case AT:
 	if (argc > optind) {
 	    if (timer != 0) {
-                fprintf(stderr, "Cannot give time two times.\n");
+                fprintf(stderr, "Cannot give time twice.\n");
                 exit(EXIT_FAILURE);
             }
-	    timer = parsetime(argc - optind, argv + optind);
+	    timer = parsetime(time(0), argc - optind, argv + optind);
 	}
 
 	if (timer == 0) {
@@ -933,14 +936,14 @@ main(int argc, char **argv)
 	if (queue_set)
 	    queue = toupper(queue);
 	else
-	    queue = DEFAULT_BATCH_QUEUE;
+	    queue = BATCH_QUEUE;
 
 	if (argc > optind) {
             if (timer != 0) {
-                fprintf(stderr, "Cannot give time two times.\n");
+                fprintf(stderr, "Cannot give time twice.\n");
                 exit(EXIT_FAILURE);
             }
-	    timer = parsetime(argc, argv);
+	    timer = parsetime(time(0), argc, argv);
         } else if (timer == 0)
 	    timer = time(NULL);
 
