@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -46,8 +46,6 @@
 
 /* File scope variables */
 
-static char rcsid[] = "$Id: panic.c,v 1.4 1997/03/12 19:36:05 ig25 Exp $";
-
 /* External variables */
 
 /* Global functions */
@@ -58,8 +56,11 @@ panic(char *a)
 /* Something fatal has happened, print error message and exit.
  */
     fprintf(stderr, "%s: %s\n", namep, a);
-    if (fcreated)
+    if (fcreated) {
+	setregid(real_gid, effective_gid);
 	unlink(atfile);
+	setregid(effective_gid, real_gid);
+    }
 
     exit(EXIT_FAILURE);
 }
@@ -78,9 +79,9 @@ perr(const char *fmt,...)
 
     perror(buf);
     if (fcreated) {
-        PRIV_START
+        setregid(real_gid, effective_gid);
 	unlink(atfile);
-        PRIV_END
+        setregid(effective_gid, real_gid);
     }
 
     exit(EXIT_FAILURE);
@@ -91,9 +92,12 @@ usage(void)
 {
 /* Print usage and exit.
  */
-    fprintf(stderr, "Usage: at [-V] [-q x] [-f file] [-m] time\n"
+    fprintf(stderr, "Usage: at [-V] [-q x] [-f file] [-mMlbv] timespec ...\n"
+            "       at [-V] [-q x] [-f file] [-mMlbv] -t time\n"
+    	    "       at -c job ...\n"
 	    "       atq [-V] [-q x]\n"
-	    "       atrm [-V] [-q x] job ...\n"
-	    "       batch [-V] [-f file] [-m]\n");
+	    "       at [ -rd ] job ...\n"
+	    "       atrm [-V] job ...\n"
+	    "       batch\n");
     exit(EXIT_FAILURE);
 }
